## v1.1.0 (2024-12-10)

### Feat

- add support for linking external GitHub issues in changelog ([3daa390](https://github.com/kmnhan/cz-changeup/commit/3daa3906d675d19a7f0e1f269735a15157d2068c))

[main b894b7e] bump: version 1.0.1 → 1.1.0
 2 files changed, 7 insertions(+), 1 deletion(-)

